@@ -10,13 +10,16 @@ use WebService::Technorati::Exception;
 sub AUTOLOAD {
     my $self=shift;
     my $change=shift;
-    my($type,$field)=$AUTOLOAD =~ /.*::((?:s|g)et)([A-Z]\w+)/
-        || WebService::Technorati::MethodNotImplementedException->throw(
-        "method not implemented: $AUTOLOAD");
+    my $class = ref($self) || $self;
+    my($type,$field) = $AUTOLOAD =~ /.*::((?:s|g)et)([A-Z]\w+)/;
+    if (! defined($field)) {
+        WebService::Technorati::MethodNotImplementedException->throw(
+            "method not implemented: $AUTOLOAD");
+    }
     $field = lc($field);
     $self->_accessible($field)
         || WebService::Technorati::AccessViolationException->throw(
-        "attribute not accessible: $field");
+        "attribute not accessible in $class: $field $AUTOLOAD");
     if ($change && $type eq 'set') {
         $self->{$field}=$change;
     }
@@ -24,10 +27,10 @@ sub AUTOLOAD {
 } # AUTOLOAD
 
 sub _accessible {
-	my $self = shift;
-	my $class = ref($self) || $self;
-	WebService::Technorati::MethodNotImplementedException->throw(
-        "abstract methond '_accessible' not implemented");
+    my $self = shift;
+    my $class = ref($self) || $self;
+    WebService::Technorati::MethodNotImplementedException->throw(
+        "abstract method '_accessible' not implemented by $class");
 }
 
 1;
